@@ -31,6 +31,18 @@ public class NotebookExample implements LifeCycleListener {
 
         Window window = new Window(WindowType.TOPLEVEL);
         window.setBorderWidth(10);
+        window.addListener(new LifeCycleListener() {
+            public void lifeCycleEvent(LifeCycleEvent event) {
+            }
+
+            public boolean lifeCycleQuery(LifeCycleEvent event) {
+                if (event.isOfType(LifeCycleEvent.Type.DESTROY)
+                        || event.isOfType(LifeCycleEvent.Type.DELETE)) {
+                    Gtk.mainQuit();
+                }
+                return true;
+            }
+        });
 
         Table table = new Table(3, 6, false);
         window.add(table);
@@ -195,7 +207,7 @@ public class NotebookExample implements LifeCycleListener {
         // Initialize GTK
         Gtk.init(args);
 
-        NotebookExample notebook = new NotebookExample();
+        new NotebookExample();
 
         Gtk.main();
     }
