@@ -9,19 +9,18 @@
 
 package org.gnu.atk;
 
-
-public class State
-{
+public class State {
     public static String getTypeName(StateType type) {
         return atk_state_type_get_name(type.getValue());
     }
-    
+
     public static StateType getTypeForName(String name) {
         return StateType.intern(atk_state_type_for_name(name));
     }
 
     native static final protected int atk_state_type_register(String name);
+
     native static final protected String atk_state_type_get_name(int type);
+
     native static final protected int atk_state_type_for_name(String name);
 }
-
