@@ -16,6 +16,7 @@ import org.gnu.glib.Error;
 import org.gnu.glib.GObject;
 import org.gnu.glib.Handle;
 import org.gnu.glib.JGException;
+import org.gnu.glib.Type;
 
 /**
  * 
@@ -26,12 +27,22 @@ import org.gnu.glib.JGException;
  * from left to right. There may be padding at the end of a row. The "rowstride"
  * value of a pixbuf, as returned by getRowstride(), indicates the number of
  * bytes between rows.
+ *
+ * @deprecated This class is part of the java-gnome 2.x family of libraries,
+ *             which, due to their inefficiency and complexity, are no longer
+ *             being maintained and have been abandoned by the java-gnome
+ *             project. This class may exist in java-gnome 4.0; look out for
+ *             <code>org.gnome.gdk.Pixbuf</code>.
  */
 public class Pixbuf extends GObject {
 
     /**
      * Constructs a Pixbuf from a handle to native resources. This should only
      * be used internally by java-gnome.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(Handle handle) {
         super(handle);
@@ -44,6 +55,10 @@ public class Pixbuf extends GObject {
      *            The name of the image file.
      * @throws FileNotFoundException
      *             if filename doesn't exist.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(String filename) throws FileNotFoundException, JGException {
         super(createWithFile(filename));
@@ -61,6 +76,10 @@ public class Pixbuf extends GObject {
      * @param preserveAspect
      * @throws FileNotFoundException
      * @throws JGException
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(String filename, int width, int height, boolean preserveAspect)
             throws FileNotFoundException, JGException {
@@ -75,6 +94,10 @@ public class Pixbuf extends GObject {
      * @param bitsPerSample
      * @param width
      * @param height
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(Colorspace colorSpace, boolean hasAlpha, int bitsPerSample,
             int width, int height) {
@@ -86,6 +109,10 @@ public class Pixbuf extends GObject {
      * Create a new Pixbuf by parsing XPM data in memory.
      * 
      * @param data
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(byte[] data) {
         super(gdk_pixbuf_new_from_xpm_data(data));
@@ -99,6 +126,10 @@ public class Pixbuf extends GObject {
      * @param data
      * @param copyPixels
      * @throws JGException
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(byte[] data, boolean copyPixels) throws JGException {
         super(createInline(data, copyPixels));
@@ -114,6 +145,10 @@ public class Pixbuf extends GObject {
      * @param srcY
      * @param width
      * @param height
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(Pixbuf srcPixbuf, int srcX, int srcY, int width, int height) {
         super(gdk_pixbuf_new_subpixbuf(srcPixbuf.getHandle(), srcX, srcY,
@@ -134,6 +169,10 @@ public class Pixbuf extends GObject {
      * @param destY
      * @param width
      * @param height
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(Drawable drawable, Colormap colormap, int srcX, int srcY,
             int destX, int destY, int width, int height) {
@@ -153,6 +192,10 @@ public class Pixbuf extends GObject {
      * @param destY
      * @param width
      * @param height
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf(Image image, Colormap colormap, int srcX, int srcY,
             int destX, int destY, int width, int height) {
@@ -215,6 +258,10 @@ public class Pixbuf extends GObject {
 
     /**
      * Return a copy of this Pixbuf.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf copy() {
         return getPixbufFromHandle(gdk_pixbuf_copy(getHandle()));
@@ -231,6 +278,10 @@ public class Pixbuf extends GObject {
      * @param dest
      * @param destX
      * @param destY
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void copyArea(int x, int y, int width, int height, Pixbuf dest,
             int destX, int destY) {
@@ -242,6 +293,10 @@ public class Pixbuf extends GObject {
      * Return the width of the pixbuf.
      * 
      * @return The width
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public int width() {
         return gdk_pixbuf_get_width(getHandle());
@@ -251,6 +306,10 @@ public class Pixbuf extends GObject {
      * Return the height of the pixbuf.
      * 
      * @return The height
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public int height() {
         return gdk_pixbuf_get_height(getHandle());
@@ -258,6 +317,10 @@ public class Pixbuf extends GObject {
 
     /**
      * Create a new pixbuf from an existing pixbuf scaled to the size provided.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf scale(int width, int height, InterpType itype) {
         return getPixbufFromHandle(gdk_pixbuf_scale_simple(getHandle(), width,
@@ -280,6 +343,10 @@ public class Pixbuf extends GObject {
      * @param scaleX
      * @param scaleY
      * @param type
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf scale(Pixbuf dest, int destX, int destY, int destWidth,
             int destHeight, double offsetX, double offsetY, double scaleX,
@@ -302,6 +369,10 @@ public class Pixbuf extends GObject {
      * @param checkSize
      * @param color1
      * @param color2
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf composite(int width, int height, InterpType type,
             int overallAlpha, int checkSize, int color1, int color2) {
@@ -328,6 +399,10 @@ public class Pixbuf extends GObject {
      * @param scaleY
      * @param type
      * @param overallAlpha
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf composite(Pixbuf dest, int destX, int destY, int destWidth,
             int destHeight, double offsetX, double offsetY, double scaleX,
@@ -360,6 +435,10 @@ public class Pixbuf extends GObject {
      * @param checkSize
      * @param color1
      * @param color2
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf composite(Pixbuf dest, int destX, int destY, int destWidth,
             int destHeight, double offsetX, double offsetY, double scaleX,
@@ -376,6 +455,10 @@ public class Pixbuf extends GObject {
      * Rotate this pixbuf and return the results as a new Pixbuf.
      * 
      * @param direction
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf rotate(PixbufRotation direction) {
         return getPixbufFromHandle(gdk_pixbuf_rotate_simple(getHandle(),
@@ -387,6 +470,10 @@ public class Pixbuf extends GObject {
      * Pixbuf.
      * 
      * @param horizontal
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf flip(boolean horizontal) {
         return getPixbufFromHandle(gdk_pixbuf_flip(getHandle(), horizontal));
@@ -394,6 +481,10 @@ public class Pixbuf extends GObject {
 
     /**
      * Returns the Colorspace for the Pixbuf.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Colorspace getColorspace() {
         return Colorspace.intern(gdk_pixbuf_get_colorspace(getHandle()));
@@ -401,6 +492,10 @@ public class Pixbuf extends GObject {
 
     /**
      * Returns the number of channels for the Pixbuf.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public int getNumChannels() {
         return gdk_pixbuf_get_n_channels(getHandle());
@@ -416,6 +511,10 @@ public class Pixbuf extends GObject {
 
     /**
      * Returns the pixel data for the Pixbuf
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public byte[] getPixels() {
         return gdk_pixbuf_get_pixels(getHandle());
@@ -424,6 +523,10 @@ public class Pixbuf extends GObject {
     /**
      * Returns the rowstride which is the number of bytes between the start of a
      * row and the start of the next row.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public int getRowstride() {
         return gdk_pixbuf_get_rowstride(getHandle());
@@ -442,6 +545,10 @@ public class Pixbuf extends GObject {
      * @param optionKeys
      * @param optionValues
      * @throws JGException
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void save(String filename, String type, String[] optionKeys,
             String[] optionValues) throws JGException {
@@ -461,6 +568,10 @@ public class Pixbuf extends GObject {
      * @param optionKeys
      * @param optionValues
      * @throws JGException
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public byte[] saveToBuffer(String type, String[] optionKeys,
             String[] optionValues) throws JGException {
@@ -486,6 +597,10 @@ public class Pixbuf extends GObject {
      * @param red
      * @param green
      * @param blue
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf addAlpha(boolean substituteColor, int red, int green, int blue) {
         return getPixbufFromHandle(gdk_pixbuf_add_alpha(getHandle(),
@@ -498,6 +613,10 @@ public class Pixbuf extends GObject {
      * doesn't have an alpha channel.
      * 
      * @param pixel
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public void fill(int pixel) {
         gdk_pixbuf_fill(getHandle(), pixel);
@@ -516,6 +635,10 @@ public class Pixbuf extends GObject {
      * @param dest
      * @param saturation
      * @param pixelate
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public Pixbuf saturateAndPixelate(Pixbuf dest, double saturation,
             boolean pixelate) {
@@ -523,12 +646,27 @@ public class Pixbuf extends GObject {
                 saturation, pixelate);
         return dest;
     }
+    
+    /**
+     * Retrieve the runtime type used by the GLib library.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
+     */
+    public static Type getType() {
+        return new Type(gdk_pixbuf_get_type());
+    }
 
     /**
      * Constructs a Pixbuf from a handle to native resources. This should only
      * be used internally by Java-Gnome. This should be used in preference to
      * {@link #Pixbuf(Handle)} unless the call is being made by a subclass of
      * Pixbuf from its own Handle constructor.
+     * @deprecated Superceeded by java-gnome 4.0; this method or constant
+     *             will no doubt exist conceptually, but it may have a different
+     *             name or signature in order that the presented API is an
+     *             algorithmic mapping of the underlying native libraries.
      */
     public static Pixbuf getPixbufFromHandle(Handle hndl) {
         if (hndl != null) {
@@ -659,5 +797,7 @@ public class Pixbuf extends GObject {
 
     native static final protected String gdk_pixbuf_get_option(Handle pixbuf,
             String key);
+    
+    native static final private int gdk_pixbuf_get_type();
 
 }
