@@ -12,10 +12,9 @@ package org.gnu.gdk;
 import org.gnu.glib.Handle;
 import org.gnu.glib.MemStruct;
 
-public class RgbCmap extends MemStruct
-{
+public class RgbCmap extends MemStruct {
 
-    native static final protected Handle gdk_rgb_cmap_new (int [] colors, int numColors);
+    native static final protected Handle gdk_rgb_cmap_new(int[] colors,
+            int numColors);
 
 }
-
