@@ -7,12 +7,13 @@
  * the terms of the GNU Library General Public License version 2.
  */
 
-
 package org.gnu.gtk;
 
-public interface TreeDragDestListener{
+public interface TreeDragDestListener {
 
-	public boolean dragDataReceived( TreeDragDest destination, TreePath path, SelectionData selectionData );
+    public boolean dragDataReceived(TreeDragDest destination, TreePath path,
+            SelectionData selectionData);
 
-	public boolean isRowDropPossible( TreeDragDest destingation, TreePath path, SelectionData selectionData );
+    public boolean isRowDropPossible(TreeDragDest destingation, TreePath path,
+            SelectionData selectionData);
 }
