@@ -9,12 +9,21 @@
 
 package org.gnu.pango;
 
-import org.gnu.javagnome.Enum;
+import org.gnu.glib.Enum;
 
 /**
  * describes how to align the lines of a PangoLayout within the available space.
  * If the PangoLayout is set to justify using pango_layout_set_justify(), then
  * this only has an effect for partial lines.
+ *
+ * @deprecated This class is part of the java-gnome 2.x family of libraries,
+ *             which, due to their inefficiency and complexity, are no longer
+ *             being maintained and have been abandoned by the java-gnome
+ *             project. This class may exist in java-gnome 4.0; look out for
+ *             <code>org.gnome.pango.Alignment</code>.
+ *             As this package was never fully implemented in java-gnome 2.x,
+ *             however, any new code written will have a considerably different
+ *             public API.
  */
 public class Alignment extends Enum {
     static final private int _LEFT = 0;
