@@ -10,7 +10,9 @@
 #include <jni.h>
 #include <atk/atk.h>
 #include "jg_jnu.h"
+#include "gtk_java.h"
 
+#include "org_gnu_atk_Relation.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -70,7 +72,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_atk_Relation_atk_1relation_1new
 {
 	AtkObject** targets_g = (AtkObject**)getPointerArrayFromHandles(env, targets);
 	gint len = (gint)(*env)->GetArrayLength(env, targets);
-	return getGObjectHandle(env, atk_relation_new(targets_g, len, (AtkRelationType)relationship));
+	return getGObjectHandle(env, G_OBJECT(atk_relation_new(targets_g, len, (AtkRelationType)relationship)));
 }
 
 /*
