@@ -10,35 +10,14 @@
 #include <jni.h>
 #include <sys/types.h>
 #include <gdk/gdk.h>
-#include "jg_jnu.h"
+#include "gtk_java.h"
 
+#include "org_gnu_gdk_EventAny.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-
-GdkEventType GdkEventAny_get_type (GdkEventAny * cptr) 
-{
-    return cptr->type;
-}
-
-/*
- * Class:     org.gnu.gdk.EventAny
- * Method:    getType
- * Signature: (I)I
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventAny_getType (JNIEnv *env, jclass cls, jobject obj) 
-{
-    GdkEventAny *obj_g = (GdkEventAny *)getPointerFromHandle(env, obj);
-    return (jint) (GdkEventAny_get_type (obj_g));
-}
-
-GdkWindow * GdkEventAny_get_window (GdkEventAny * cptr) 
-{
-    return cptr->window;
-}
-
 /*
  * Class:     org.gnu.gdk.EventAny
  * Method:    getWindow
@@ -46,12 +25,7 @@ GdkWindow * GdkEventAny_get_window (GdkEventAny * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventAny_getWindow (JNIEnv *env, jclass cls, jobject obj) 
 {
     GdkEventAny *obj_g = (GdkEventAny *)getPointerFromHandle(env, obj);
-    return getHandleFromPointer(env, GdkEventAny_get_window (obj_g));
-}
-
-gboolean GdkEventAny_get_send_event (GdkEventAny * cptr) 
-{
-    return cptr->send_event;
+    return getGObjectHandleAndRef(env, (GObject *)obj_g->window);
 }
 
 /*
@@ -62,7 +36,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_EventAny_getSendEvent (JNIEnv *env,
     jobject obj) 
 {
     GdkEventAny *obj_g = (GdkEventAny *)getPointerFromHandle(env, obj);
-    return (jboolean) (GdkEventAny_get_send_event (obj_g));
+    return (jboolean) obj_g->send_event;
 }
 
 
