@@ -12,6 +12,7 @@
 #include <gdk/gdk.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gdk_EventClient.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -43,11 +44,11 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventClient_getSendEvent (JNIEnv *env, j
  * Class:     org.gnu.gdk.EventClient
  * Method:    getMessageType
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventClient_getMessageType (JNIEnv *env, jclass cls, 
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventClient_getMessageType (JNIEnv *env, jclass cls, 
     jobject obj) 
 {
     GdkEventClient *obj_g = (GdkEventClient *)getPointerFromHandle(env, obj);
-    return (jint) obj_g->message_type;
+    return getStructHandle(env, obj_g->message_type, NULL, (JGFreeFunc) g_free);
 }
 
 /*
