@@ -12,6 +12,7 @@
 #include <gdk/gdk.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gdk_EventNoExpose.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -25,7 +26,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventNoExpose_getWindow (JNIEnv *env,
     obj) 
 {
     GdkEventNoExpose *obj_g = (GdkEventNoExpose *)getPointerFromHandle(env, obj);
-    return getGObjectHandle(env, (GObject *)obj_g->window);
+    return getGObjectHandleAndRef(env, (GObject *)obj_g->window);
 }
 
 /*
