@@ -9,25 +9,13 @@
 
 #include <jni.h>
 #include <gdk/gdk.h>
-#include "jg_jnu.h"
+#include "gtk_java.h"
 
-
-#ifndef _Included_org_gnu_gdk_EventOwnerChange
-#define _Included_org_gnu_gdk_EventOwnerChange
+#include "org_gnu_gdk_EventOwnerChange.h"
 #ifdef __cplusplus
-extern "C" {
-#endif
-
-/*
- * Class:     org_gnu_gdk_EventOwnerChange
- * Method:    getType
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventOwnerChange_getType
-  (JNIEnv *env, jclass cls, jobject event)
+extern "C" 
 {
-	GdkEventOwnerChange* event_g = (GdkEventOwnerChange*)getPointerFromHandle(env, event);
-	return (jint)event_g->type;
-}
+#endif
 
 /*
  * Class:     org_gnu_gdk_EventOwnerChange
@@ -36,8 +24,8 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventOwnerChange_getType
 JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventOwnerChange_getWindow
   (JNIEnv *env, jclass cls, jobject event)
 {
-	GdkEventOwnerChange* event_g = (GdkEventOwnerChange*)getPointerFromHandle(env, event);
-	return getHandleFromPointer(env, event_g->window);
+    GdkEventOwnerChange* event_g = (GdkEventOwnerChange*)getPointerFromHandle(env, event);
+    return getGObjectHandleAndRef(env, (GObject *)event_g->window);
 }
 
 /*
@@ -47,11 +35,11 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventOwnerChange_getWindow
 JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventOwnerChange_getSendEvent
   (JNIEnv *env, jclass cls, jobject event)
 {
-	GdkEventOwnerChange* event_g = (GdkEventOwnerChange*)getPointerFromHandle(env, event);
-	return (jint)event_g->send_event;
+    GdkEventOwnerChange* event_g = (GdkEventOwnerChange*)getPointerFromHandle(env, event);
+    return (jint)event_g->send_event;
 }
 
 #ifdef __cplusplus
 }
-#endif
+
 #endif
