@@ -9,34 +9,14 @@
 
 #include <jni.h>
 #include <gdk/gdk.h>
-#include "jg_jnu.h"
+#include "gtk_java.h"
 
+#include "org_gnu_gdk_EventVisibility.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-GdkEventType GdkEventVisibility_get_type (GdkEventVisibility * cptr) 
-{
-    return cptr->type;
-}
-
-/*
- * Class:     org.gnu.gdk.EventVisibility
- * Method:    getType
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventVisibility_getType (JNIEnv *env, jclass cls, jobject 
-    obj) 
-{
-    GdkEventVisibility *obj_g = (GdkEventVisibility *)getPointerFromHandle(env, obj);
-    return (jint) (GdkEventVisibility_get_type (obj_g));
-}
-
-GdkWindow * GdkEventVisibility_get_window (GdkEventVisibility * cptr) 
-{
-    return cptr->window;
-}
-
 /*
  * Class:     org.gnu.gdk.EventVisibility
  * Method:    getWindow
@@ -45,12 +25,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_EventVisibility_getWindow (JNIEnv *en
     jobject obj) 
 {
     GdkEventVisibility *obj_g = (GdkEventVisibility *)getPointerFromHandle(env, obj);
-    return getHandleFromPointer(env, GdkEventVisibility_get_window (obj_g));
-}
-
-gboolean GdkEventVisibility_get_send_event (GdkEventVisibility * cptr) 
-{
-    return cptr->send_event;
+    return getGObjectHandle(env, (GObject *)obj_g->window);
 }
 
 /*
@@ -61,12 +36,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_EventVisibility_getSendEvent (JNIEnv
     cls, jobject obj) 
 {
     GdkEventVisibility *obj_g = (GdkEventVisibility *)getPointerFromHandle(env, obj);
-    return (jboolean) (GdkEventVisibility_get_send_event (obj_g));
-}
-
-GdkVisibilityState GdkEventVisibility_get_state (GdkEventVisibility * cptr) 
-{
-    return cptr->state;
+    return (jboolean) obj_g->send_event;
 }
 
 /*
@@ -77,7 +47,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_EventVisibility_getState (JNIEnv *env, j
     obj) 
 {
     GdkEventVisibility *obj_g = (GdkEventVisibility *)getPointerFromHandle(env, obj);
-    return (jint) (GdkEventVisibility_get_state (obj_g));
+    return (jint) obj_g->state;
 }
 
 
