@@ -9,13 +9,16 @@
 
 #include <jni.h>
 #include <gdk/gdk.h>
+#include "gtk_java.h"
 #include "jg_jnu.h"
 
+#include "org_gnu_gdk_Gdk.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_input_set_extension_events
@@ -28,7 +31,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1input_1set_1extension_1events (
     GdkExtensionMode mode_g = (GdkExtensionMode) mode;
     gdk_input_set_extension_events (window_g, mask_g, mode_g);
 }
-
+#endif
 
 /*
  * Class:     org.gnu.gdk.Gdk
@@ -40,67 +43,6 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1flush (JNIEnv *env, jclass cls)
     gdk_flush ();
 }
 
-/*
- * Class:     org.gnu.gdk.Gdk
- * Method:    gdk_set_locale
- * Signature: ()java.lang.String
- */
-JNIEXPORT jstring JNICALL Java_org_gnu_gdk_Gdk_gdk_1set_1locale (JNIEnv *env, jclass cls) 
-{
-    gchar *result_g = gdk_set_locale ();
-    return (*env)->NewStringUTF(env, result_g);
-}
-
-/*
- * Class:     org.gnu.gdk.Gdk
- * Method:    gdk_screen_width
- * Signature: ()I
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1screen_1width (JNIEnv *env, jclass cls) 
-{
-    jint result_j = (jint) (gdk_screen_width ());
-    return result_j;
-}
-
-/*
- * Class:     org.gnu.gdk.Gdk
- * Method:    gdk_screen_height
- * Signature: ()I
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1screen_1height (JNIEnv *env, jclass cls) 
-{
-    {
-        jint result_j = (jint) (gdk_screen_height ());
-        return result_j;
-    }
-}
-
-/*
- * Class:     org.gnu.gdk.Gdk
- * Method:    gdk_screen_width_mm
- * Signature: ()I
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1screen_1width_1mm (JNIEnv *env, jclass cls) 
-{
-    {
-        jint result_j = (jint) (gdk_screen_width_mm ());
-        return result_j;
-    }
-}
-
-/*
- * Class:     org.gnu.gdk.Gdk
- * Method:    gdk_screen_height_mm
- * Signature: ()I
- */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1screen_1height_1mm (JNIEnv *env, jclass cls) 
-{
-    {
-        jint result_j = (jint) (gdk_screen_height_mm ());
-        return result_j;
-    }
-}
-
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_beep
@@ -113,6 +55,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1beep (JNIEnv *env, jclass cls)
     }
 }
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_set_show_events
@@ -126,7 +69,9 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1set_1show_1events (JNIEnv *env,
         gdk_set_show_events (showEvents_g);
     }
 }
+#endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_get_show_events
@@ -139,7 +84,9 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1get_1show_1events (JNIEnv *
         return result_j;
     }
 }
+#endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_keyval_name
@@ -151,7 +98,9 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyval_1name (JNIEnv *env, j
     gchar *result_g = gdk_keyval_name ((gint32)keyval);
     return (*env)->NewStringUTF(env, result_g);
 }
+#endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_keyval_from_name
@@ -165,7 +114,9 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyval_1from_1name (JNIEnv *env
     (*env)->ReleaseStringUTFChars(env, keyvalName, keyvalName_g);
     return result_j;
 }
+#endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_keyval_to_upper
@@ -180,7 +131,9 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyval_1to_1upper (JNIEnv *env,
         return result_j;
     }
 }
+#endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_keyval_to_lower
@@ -195,7 +148,9 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyval_1to_1lower (JNIEnv *env,
         return result_j;
     }
 }
+#endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_keyval_is_upper
@@ -210,7 +165,9 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyval_1is_1upper (JNIEnv *
         return result_j;
     }
 }
+#endif
 
+#ifdef ZERO
 /*
  * Class:     org.gnu.gdk.Gdk
  * Method:    gdk_keyval_is_lower
@@ -225,8 +182,10 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyval_1is_1lower (JNIEnv *
         return result_j;
     }
 }
+#endif
 
 
+#ifdef ZERO
 JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1init
 (JNIEnv *env, jclass cls, jintArray argc, jobjectArray argv)
 {
@@ -237,7 +196,9 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1init
     (*env)->ReleaseIntArrayElements (env, argc, (jint *) argc_g, 0);
     freeStringArray(env, argv, argv_g_arr);
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1init_1check
 (JNIEnv *env, jclass cls, jintArray argc, jobjectArray argv)
 {
@@ -249,7 +210,9 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1init_1check
     freeStringArray(env, argv, argv_g_arr);
     return ret;
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1parse_1args
 (JNIEnv *env, jclass cls, jintArray argc, jobjectArray argv)
 {
@@ -260,13 +223,17 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1parse_1args
     (*env)->ReleaseIntArrayElements (env, argc, (jint *) argc_g, 0);
     freeStringArray(env, argv, argv_g_arr);
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT jstring JNICALL Java_org_gnu_gdk_Gdk_gdk_1get_1program_1class
 (JNIEnv *env, jclass cls)
 {
     return (*env)->NewStringUTF(env, gdk_get_program_class());
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1set_1program_1class
 (JNIEnv *env, jclass cls, jstring program_class)
 {
@@ -274,103 +241,33 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1set_1program_1class
     gdk_set_program_class(program_class_g);
     (*env)->ReleaseStringUTFChars(env, program_class, program_class_g);
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1error_1trap_1push
 (JNIEnv *env, jclass cls)
 {
     gdk_error_trap_push();
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1error_1trap_1pop
 (JNIEnv *env, jclass cls)
 {
     return (jint)gdk_error_trap_pop();
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT jstring JNICALL Java_org_gnu_gdk_Gdk_gdk_1get_1display_1arg_1name
 (JNIEnv *env, jclass cls)
 {
     return (*env)->NewStringUTF(env, gdk_get_display_arg_name());
 }
+#endif
 
-JNIEXPORT jstring JNICALL Java_org_gnu_gdk_Gdk_gdk_1get_1display
-(JNIEnv *env, jclass cls)
-{
-    return (*env)->NewStringUTF(env, gdk_get_display());
-}
-
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1pointer_1grab
-(JNIEnv *env, jclass cls, jobject window, jboolean owner_events, jint event_mask, jobject confine_to, jobject cursor, jint time_)
-{
-    GdkWindow * window_g = (GdkWindow *)getPointerFromHandle(env, window);
-    gboolean owner_events_g = (gboolean)owner_events;
-    GdkEventMask event_mask_g = (GdkEventMask)event_mask;
-    GdkWindow * confine_to_g = (GdkWindow *)getPointerFromHandle(env, confine_to);
-    GdkCursor * cursor_g = (GdkCursor *)getPointerFromHandle(env, cursor);
-    guint32 time__g = (guint32)time_;
-    return (jint)gdk_pointer_grab(window_g, owner_events_g, event_mask_g, confine_to_g, cursor_g, time__g);
-}
-
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyboard_1grab
-(JNIEnv *env, jclass cls, jobject window, jboolean owner_events, jint time_)
-{
-    GdkWindow * window_g = (GdkWindow *)getPointerFromHandle(env, window);
-    gboolean owner_events_g = (gboolean)owner_events;
-    guint32 time__g = (guint32)time_;
-    return (jint)gdk_keyboard_grab(window_g, owner_events_g, time__g);
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1pointer_1ungrab
-(JNIEnv *env, jclass cls, jint time_)
-{
-    guint32 time__g = (guint32)time_;
-    gdk_pointer_ungrab(time__g);
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1keyboard_1ungrab
-(JNIEnv *env, jclass cls, jint time_)
-{
-    guint32 time__g = (guint32)time_;
-    gdk_keyboard_ungrab(time__g);
-}
-
-JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1pointer_1is_1grabbed
-(JNIEnv *env, jclass cls)
-{
-    return (jboolean)gdk_pointer_is_grabbed();
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1set_1double_1click_1time
-(JNIEnv *env, jclass cls, jint msec)
-{
-    guint msec_g = (guint)msec;
-    gdk_set_double_click_time(msec_g);
-}
-
-JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1rectangle_1intersect
-(JNIEnv *env, jclass cls, jobject src1, jobject src2, jobject dest)
-{
-    GdkRectangle * src1_g = (GdkRectangle *)getPointerFromHandle(env, src1);
-    GdkRectangle * src2_g = (GdkRectangle *)getPointerFromHandle(env, src2);
-    GdkRectangle * dest_g = (GdkRectangle *)getPointerFromHandle(env, dest);
-    return (jboolean)gdk_rectangle_intersect(src1_g, src2_g, dest_g);
-}
-
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1rectangle_1union
-(JNIEnv *env, jclass cls, jobject src1, jobject src2, jobject dest)
-{
-    GdkRectangle * src1_g = (GdkRectangle *)getPointerFromHandle(env, src1);
-    GdkRectangle * src2_g = (GdkRectangle *)getPointerFromHandle(env, src2);
-    GdkRectangle * dest_g = (GdkRectangle *)getPointerFromHandle(env, dest);
-    gdk_rectangle_union(src1_g, src2_g, dest_g);
-}
-
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Gdk_gdk_1rectangle_1get_1type
-(JNIEnv *env, jclass cls)
-{
-    return (jint)gdk_rectangle_get_type();
-}
-
+#ifdef ZERO
 JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1event_1send_1client_1message
 (JNIEnv *env, jclass cls, jobject event, jint winid)
 {
@@ -378,14 +275,18 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1event_1send_1client_1messag
     GdkNativeWindow winid_g = (GdkNativeWindow)winid;
     return (jboolean)gdk_event_send_client_message(event_g, winid_g);
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1event_1send_1clientmessage_1toall
 (JNIEnv *env, jclass cls, jobject event)
 {
     GdkEvent * event_g = (GdkEvent *)getPointerFromHandle(env, event);
     gdk_event_send_clientmessage_toall(event_g);
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1event_1send_1client_1message_1for_1display
 (JNIEnv *env, jclass cls, jobject display, jobject event, jint winid)
 {
@@ -394,12 +295,15 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gdk_Gdk_gdk_1event_1send_1client_1messag
     GdkNativeWindow winid_g = (GdkNativeWindow)winid;
     return (jboolean)gdk_event_send_client_message_for_display(display_g, event_g, winid_g);
 }
+#endif
 
+#ifdef ZERO
 JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1notify_1startup_1complete
 (JNIEnv *env, jclass cls)
 {
     gdk_notify_startup_complete();
 }
+#endif
 
 JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1threads_1enter
 (JNIEnv *env, jclass cls)
@@ -419,6 +323,16 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Gdk_gdk_1threads_1init
     gdk_threads_init();
 }
 
+/*
+ * Class:     org.gnu.gdk.Gdk
+ * Method:    gdk_pango_context_get
+ */
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Gdk_gdk_1pango_1context_1get 
+(JNIEnv *env, jclass cls)
+{
+    return getGObjectHandle(env, G_OBJECT(gdk_pango_context_get()));
+}
+
 #ifdef __cplusplus
 }
 
