@@ -12,6 +12,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gdk_Segment.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -32,7 +33,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Segment_gdk_1segment_1new
     return getStructHandle(env, seg, NULL, g_free);
 }
 
-gint32 GdkSegment_get_x1 (GdkSegment * cptr) 
+static gint32 GdkSegment_get_x1 (GdkSegment * cptr) 
 {
     return cptr->x1;
 }
@@ -47,7 +48,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Segment_getX1 (JNIEnv *env, jclass cls,
     return (jint) (GdkSegment_get_x1 (obj_g));
 }
 
-void GdkSegment_set_x1 (GdkSegment * cptr, gint32 x1) 
+static void GdkSegment_set_x1 (GdkSegment * cptr, gint32 x1) 
 {
     cptr->x1 = x1;
 }
@@ -56,14 +57,14 @@ void GdkSegment_set_x1 (GdkSegment * cptr, gint32 x1)
  * Class:     org.gnu.gdk.Segment
  * Method:    setX1
  */
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setX1 (JNIEnv *env, jobject obj, jint x1) 
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setX1 (JNIEnv *env, jclass klass, jobject obj, jint x1)
 {
     GdkSegment *obj_g = (GdkSegment *)getPointerFromHandle(env, obj);
     gint32 x1_g = (gint32) x1;
     GdkSegment_set_x1 (obj_g, x1_g);
 }
 
-gint32 GdkSegment_get_y1 (GdkSegment * cptr) 
+static gint32 GdkSegment_get_y1 (GdkSegment * cptr) 
 {
     return cptr->y1;
 }
@@ -78,7 +79,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Segment_getY1 (JNIEnv *env, jclass cls,
     return (jint) (GdkSegment_get_y1 (obj_g));
 }
 
-void GdkSegment_set_y1 (GdkSegment * cptr, gint32 y1) 
+static void GdkSegment_set_y1 (GdkSegment * cptr, gint32 y1) 
 {
     cptr->y1 = y1;
 }
@@ -87,14 +88,14 @@ void GdkSegment_set_y1 (GdkSegment * cptr, gint32 y1)
  * Class:     org.gnu.gdk.Segment
  * Method:    setY1
  */
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setY1 (JNIEnv *env, jobject obj, jint y1) 
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setY1 (JNIEnv *env, jclass klass, jobject obj, jint y1) 
 {
     GdkSegment *obj_g = (GdkSegment *)getPointerFromHandle(env, obj);
     gint32 y1_g = (gint32) y1;
     GdkSegment_set_y1 (obj_g, y1_g);
 }
 
-gint32 GdkSegment_get_x2 (GdkSegment * cptr) 
+static gint32 GdkSegment_get_x2 (GdkSegment * cptr) 
 {
     return cptr->x2;
 }
@@ -109,7 +110,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Segment_getX2 (JNIEnv *env, jclass cls,
     return (jint) (GdkSegment_get_x2 (obj_g));
 }
 
-void GdkSegment_set_x2 (GdkSegment * cptr, gint32 x2) 
+static void GdkSegment_set_x2 (GdkSegment * cptr, gint32 x2) 
 {
     cptr->x2 = x2;
 }
@@ -118,14 +119,14 @@ void GdkSegment_set_x2 (GdkSegment * cptr, gint32 x2)
  * Class:     org.gnu.gdk.Segment
  * Method:    setX2
  */
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setX2 (JNIEnv *env, jobject obj, jint x2) 
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setX2 (JNIEnv *env, jclass klass, jobject obj, jint x2) 
 {
     GdkSegment *obj_g = (GdkSegment *)getPointerFromHandle(env, obj);
     gint32 x2_g = (gint32) x2;
     GdkSegment_set_x2 (obj_g, x2_g);
 }
 
-gint32 GdkSegment_get_y2 (GdkSegment * cptr) 
+static gint32 GdkSegment_get_y2 (GdkSegment * cptr) 
 {
     return cptr->y2;
 }
@@ -140,7 +141,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Segment_getY2 (JNIEnv *env, jclass cls,
     return (jint) (GdkSegment_get_y2 (obj_g));
 }
 
-void GdkSegment_set_y2 (GdkSegment * cptr, gint32 y2) 
+static void GdkSegment_set_y2 (GdkSegment * cptr, gint32 y2) 
 {
     cptr->y2 = y2;
 }
@@ -149,7 +150,7 @@ void GdkSegment_set_y2 (GdkSegment * cptr, gint32 y2)
  * Class:     org.gnu.gdk.Segment
  * Method:    setY2
  */
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setY2 (JNIEnv *env, jobject obj, jint y2) 
+JNIEXPORT void JNICALL Java_org_gnu_gdk_Segment_setY2 (JNIEnv *env, jclass klass, jobject obj, jint y2) 
 {
     GdkSegment *obj_g = (GdkSegment *)getPointerFromHandle(env, obj);
     gint32 y2_g = (gint32) y2;
