@@ -12,6 +12,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gdk_Window.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -44,6 +45,28 @@ JNIEXPORT jint JNICALL Java_org_gnu_gdk_Window_gdk_1window_1get_1window_1type (J
     return (jint) (gdk_window_get_window_type (window_g));
 }
 
+/*
+ * Class:     org.gnu.gdk.Window
+ * Method:    gdk_window_get_pointer
+ */
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Window_gdk_1window_1get_1pointer (JNIEnv *env, 
+    jclass cls, jobject window, jintArray x, jintArray y, jintArray mod_type) 
+{
+    GdkWindow *window_g = (GdkWindow *)getPointerFromHandle(env, window);
+    gint *x_g = (gint *) (*env)->GetIntArrayElements (env, x, NULL);
+    gint *y_g = (gint *) (*env)->GetIntArrayElements (env, y, NULL);
+	GdkModifierType *modType_g = (GdkModifierType *) (*env)->GetIntArrayElements (env, mod_type, NULL);
+	GdkWindow* result = gdk_window_get_pointer(window_g, x_g, y_g, modType_g);
+	(*env)->ReleaseIntArrayElements (env, x, (jint *) x_g, 0);
+    (*env)->ReleaseIntArrayElements (env, y, (jint *) y_g, 0);
+    (*env)->ReleaseIntArrayElements (env, mod_type, (jint *) modType_g, 0);
+	
+	if(result == NULL)
+		return NULL;
+		
+	return getGObjectHandleAndRef(env, (GObject *)result);
+}
+
 /*
  * Class:     org.gnu.gdk.Window
  * Method:    gdk_window_destroy
@@ -63,7 +86,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Window_gdk_1window_1at_1pointer (JNIE
 {
     gint x;
     gint y;
-    return getGObjectHandle(env, (GObject *)gdk_window_at_pointer(&x, &y));
+    return getGObjectHandleAndRef(env, (GObject *)gdk_window_at_pointer(&x, &y));
 }
 
 /*
@@ -602,13 +625,14 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Window_gdk_1window_1get_1root_1origin (J
  * Class:     org.gnu.gdk.Window
  * Method:    gdk_window_get_frame_extents
  */
-JNIEXPORT void JNICALL Java_org_gnu_gdk_Window_gdk_1window_1get_1frame_1extents (JNIEnv *env, 
-    jclass cls, jobject window, jobject rect) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Window_gdk_1window_1get_1frame_1extents
+		(JNIEnv *env, jclass cls, jobject window) 
 {
     GdkWindow *window_g = (GdkWindow *)getPointerFromHandle(env, window);
-    GdkRectangle *rect_g = g_new(GdkRectangle, 1);
-    gdk_window_get_frame_extents (window_g, rect_g);
-    updateHandle(env, rect, rect_g);
+    GdkRectangle *rect = g_new(GdkRectangle, 1);
+    gdk_window_get_frame_extents (window_g, rect);
+    return getGBoxedHandle(env, rect, GDK_TYPE_RECTANGLE, NULL,
+    		(GBoxedFreeFunc) g_free);
 }
 
 /*
@@ -904,11 +928,11 @@ JNIEXPORT void JNICALL Java_org_gnu_gdk_Window_gdk_1window_1invalidate_1region (
  * Class:     org.gnu.gdk.Window
  * Method:    gdk_window_get_update_area
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gdk_Window_gdk_1window_1get_1update_1area (JNIEnv *env, 
+JNIEXPORT jobject JNICALL Java_org_gnu_gdk_Window_gdk_1window_1get_1update_1area (JNIEnv *env, 
     jclass cls, jobject window) 
 {
     GdkWindow *window_g = (GdkWindow *)getPointerFromHandle(env, window);
-    return (jint)gdk_window_get_update_area (window_g);
+    return getStructHandle(env, gdk_window_get_update_area (window_g), NULL, (JGFreeFunc) g_free);
 }
 
 /*
