@@ -11,16 +11,14 @@
 #include <gtk/gtk.h>
 #include <jg_jnu.h>
 #include "gtk_java.h"
-
+#include "handleCallbackAction.h"
 #ifndef _Included_org_gnu_gtk_ActionEntry
 #define _Included_org_gnu_gtk_ActionEntry
+#include "org_gnu_gtk_ActionEntry.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-
-void handleCallbackAction(GtkAction* action, gpointer userData);
-
 /*
  * Class:     org_gnu_gtk_ActionEntry
  * Method:    allocate
