@@ -9,8 +9,10 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_EventBox.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -32,7 +34,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_EventBox_gtk_1event_1box_1get_1type (JNI
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_EventBox_gtk_1event_1box_1new (JNIEnv *env, jclass cls) 
 {
-    return getHandleFromPointer(env, gtk_event_box_new ());
+    return getGObjectHandle(env, (GObject *) gtk_event_box_new ());
 }
 
 /*
