@@ -12,12 +12,13 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_FontSelectionDialog.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-GtkFontSelection * GtkFontSelectionDialog_get_fontsel (GtkFontSelectionDialog * cptr) 
+static GtkFontSelection * GtkFontSelectionDialog_get_fontsel (GtkFontSelectionDialog * cptr) 
 {
     return (GtkFontSelection*)cptr->fontsel;
 }
@@ -33,7 +34,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FontSelectionDialog_getFontsel (JNIEn
     return getGObjectHandle(env, (GObject *) GtkFontSelectionDialog_get_fontsel (cptr_g));
 }
 
-GtkWidget * GtkFontSelectionDialog_get_main_vbox (GtkFontSelectionDialog * cptr) 
+static GtkWidget * GtkFontSelectionDialog_get_main_vbox (GtkFontSelectionDialog * cptr) 
 {
     return cptr->main_vbox;
 }
@@ -49,7 +50,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FontSelectionDialog_getMainVbox (JNIE
     return getGObjectHandle(env, (GObject *) GtkFontSelectionDialog_get_main_vbox (cptr_g));
 }
 
-GtkButton * GtkFontSelectionDialog_get_ok_button (GtkFontSelectionDialog * cptr) 
+static GtkButton * GtkFontSelectionDialog_get_ok_button (GtkFontSelectionDialog * cptr) 
 {
     return (GtkButton*)cptr->ok_button;
 }
@@ -65,7 +66,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FontSelectionDialog_getOkButton (JNIE
     return getGObjectHandle(env, (GObject *) GtkFontSelectionDialog_get_ok_button (cptr_g));
 }
 
-GtkButton * GtkFontSelectionDialog_get_apply_button (GtkFontSelectionDialog * cptr) 
+static GtkButton * GtkFontSelectionDialog_get_apply_button (GtkFontSelectionDialog * cptr) 
 {
     return (GtkButton*)cptr->apply_button;
 }
@@ -81,7 +82,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FontSelectionDialog_getApplyButton (J
     return getGObjectHandle(env, (GObject *) GtkFontSelectionDialog_get_apply_button (cptr_g));
 }
 
-GtkButton * GtkFontSelectionDialog_get_cancel_button (GtkFontSelectionDialog * cptr) 
+static GtkButton * GtkFontSelectionDialog_get_cancel_button (GtkFontSelectionDialog * cptr) 
 {
     return (GtkButton*)cptr->cancel_button;
 }
@@ -97,7 +98,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_FontSelectionDialog_getCancelButton (
     return getGObjectHandle(env, (GObject *) GtkFontSelectionDialog_get_cancel_button (cptr_g));
 }
 
-gint32 GtkFontSelectionDialog_get_dialog_width (GtkFontSelectionDialog * cptr) 
+static gint32 GtkFontSelectionDialog_get_dialog_width (GtkFontSelectionDialog * cptr) 
 {
     return cptr->dialog_width;
 }
@@ -113,7 +114,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_FontSelectionDialog_getDialogWidth (JNIE
     return (jint) (GtkFontSelectionDialog_get_dialog_width (cptr_g));
 }
 
-gboolean GtkFontSelectionDialog_get_auto_resize (GtkFontSelectionDialog * cptr) 
+static gboolean GtkFontSelectionDialog_get_auto_resize (GtkFontSelectionDialog * cptr) 
 {
     return cptr->auto_resize;
 }
