@@ -12,12 +12,13 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_GammaCurve.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-GtkWidget * GtkGammaCurve_get_table (GtkGammaCurve * cptr) 
+static GtkWidget * GtkGammaCurve_get_table (GtkGammaCurve * cptr) 
 {
     return cptr->table;
 }
@@ -32,7 +33,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_GammaCurve_getTable (JNIEnv *env, jcl
     return getGObjectHandle(env, (GObject *) GtkGammaCurve_get_table (cptr_g));
 }
 
-GtkWidget * GtkGammaCurve_get_curve (GtkGammaCurve * cptr) 
+static GtkWidget * GtkGammaCurve_get_curve (GtkGammaCurve * cptr) 
 {
     return cptr->curve;
 }
@@ -47,7 +48,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_GammaCurve_getCurve (JNIEnv *env, jcl
     return getGObjectHandle (env, (GObject *) GtkGammaCurve_get_curve (cptr_g));
 }
 
-gdouble GtkGammaCurve_get_gamma (GtkGammaCurve * cptr) 
+static gdouble GtkGammaCurve_get_gamma (GtkGammaCurve * cptr) 
 {
     return cptr->gamma;
 }
@@ -63,7 +64,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gtk_GammaCurve_getGamma (JNIEnv *env, jcl
     return (jdouble) (GtkGammaCurve_get_gamma (cptr_g));
 }
 
-GtkWidget * GtkGammaCurve_get_gamma_dialog (GtkGammaCurve * cptr) 
+static GtkWidget * GtkGammaCurve_get_gamma_dialog (GtkGammaCurve * cptr) 
 {
     return cptr->gamma_dialog;
 }
@@ -79,7 +80,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_GammaCurve_getGammaDialog (JNIEnv *en
     return getGObjectHandle(env, (GObject *) GtkGammaCurve_get_gamma_dialog (cptr_g));
 }
 
-GtkWidget * GtkGammaCurve_get_gamma_text (GtkGammaCurve * cptr) 
+static GtkWidget * GtkGammaCurve_get_gamma_text (GtkGammaCurve * cptr) 
 {
     return cptr->gamma_text;
 }
