@@ -9,8 +9,10 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_HBox.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -34,7 +36,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_HBox_gtk_1hbox_1new (JNIEnv *env, jcl
 {
     gboolean homogenous_g = (gboolean) homogenous;
     gint32 spacing_g = (gint32) spacing;
-    return getHandleFromPointer(env, gtk_hbox_new (homogenous_g, spacing_g));
+    return getGObjectHandle(env, (GObject *) gtk_hbox_new (homogenous_g, spacing_g));
 }
 
 
