@@ -14,6 +14,7 @@
 
 #ifndef _Included_org_gnu_gtk_IconInfo
 #define _Included_org_gnu_gtk_IconInfo
+#include "org_gnu_gtk_IconInfo.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -113,16 +114,15 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_IconInfo_gtk_1icon_1info_1get_1embed
  * Method:    gtk_icon_info_get_attach_points
  */
 JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_IconInfo_gtk_1icon_1info_1get_1attach_1points
-  (JNIEnv *env, jclass cls, jobject info, jintArray points, jint numPoints)
+  (JNIEnv *env, jclass cls, jobject info, jobjectArray points, jint numPoints)
 {
 	GtkIconInfo* info_g = (GtkIconInfo*)getPointerFromHandle(env, info);
 	GdkPoint** point = g_malloc(sizeof(GdkPoint*) * (gint)numPoints);
-	jint* elements = (*env)->GetIntArrayElements(env, points, NULL);
 	int index;
 	
 	for (index = 0; index < (gint)numPoints; index++)
 	{
-		point[index] = (GdkPoint*)elements[index];
+	  point[index] = (GdkPoint*)getPointerFromHandle(env, (*env)->GetObjectArrayElement(env, points, index));
 	}
 	return gtk_icon_info_get_attach_points(info_g, point, (gint *)&numPoints);
 }
