@@ -9,10 +9,12 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
 #ifndef _Included_org_gnu_gtk_IconTheme
 #define _Included_org_gnu_gtk_IconTheme
+#include "org_gnu_gtk_IconTheme.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -34,7 +36,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1get_1type
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1new
   (JNIEnv *env, jclass cls)
 {
-	return getHandleFromPointer(env, gtk_icon_theme_new());
+	return getGObjectHandle(env, (GObject *) gtk_icon_theme_new());
 }
 
 /*
@@ -44,7 +46,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1new
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1get_1default
   (JNIEnv *env, jclass cls)
 {
-	return getHandleFromPointer(env, gtk_icon_theme_get_default());
+	return getGObjectHandle(env, (GObject *) gtk_icon_theme_get_default());
 }
 
 /*
@@ -55,7 +57,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1get_1for_
   (JNIEnv *env, jclass cls, jobject screen)
 {
 	GdkScreen* screen_g = (GdkScreen*)getPointerFromHandle(env, screen);
-	return getHandleFromPointer(env, gtk_icon_theme_get_for_screen(screen_g));
+	return getGObjectHandle(env, (GObject *) gtk_icon_theme_get_for_screen(screen_g));
 }
 
 /*
@@ -173,10 +175,13 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1has_1ico
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1lookup_1icon
   (JNIEnv *env, jclass cls, jobject itheme, jstring name, jint size, jint flags)
 {
+	GtkIconInfo *icon_info;
 	GtkIconTheme* itheme_g = (GtkIconTheme*)getPointerFromHandle(env, itheme);
 	const gchar* p = (*env)->GetStringUTFChars(env, name, NULL);
-	jobject ret = getHandleFromPointer(env,
-			gtk_icon_theme_lookup_icon(itheme_g, p, (gint)size, (GtkIconLookupFlags)flags));
+	icon_info = gtk_icon_theme_lookup_icon(itheme_g, p, (gint) size,
+			(GtkIconLookupFlags) flags);
+	jobject ret = getGBoxedHandle(env, icon_info, GTK_TYPE_ICON_INFO, NULL,
+			(GBoxedFreeFunc) gtk_icon_info_free);
 	(*env)->ReleaseStringUTFChars(env, name, p);
 	return ret;
 }
@@ -186,16 +191,18 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1lookup_1i
  * Method:    gtk_icon_theme_load_icon
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1load_1icon
-  (JNIEnv *env, jclass cls, jobject itheme, jstring name, jint size, jint flags, jobject error)
+  (JNIEnv *env, jclass cls, jobject itheme, jstring name, jint size, jint flags)
 {
 	GtkIconTheme* itheme_g = (GtkIconTheme*)getPointerFromHandle(env, itheme);
 	const gchar* p = (*env)->GetStringUTFChars(env, name, NULL);
 	GError* e = NULL;
-	jobject value =  getHandleFromPointer(env,
+	jobject value =  getGObjectHandleAndRef(env,(GObject *)
 			gtk_icon_theme_load_icon(itheme_g, p, (gint)size, (GtkIconLookupFlags)flags, &e));
 	(*env)->ReleaseStringUTFChars(env, name, p);
-	if (NULL != e)
-    	updateHandle(env, error, e);
+	if (e != NULL)	{
+    	g_error_free(e);
+    	return NULL;
+	}
 	return value;
 }
 
@@ -212,7 +219,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1list
 	guint len;
 	jobjectArray array;
 	jclass strCls;
-	int index;
+	guint index;
 
 	(*env)->ReleaseStringUTFChars(env, context, p);
  	if (NULL == list)
@@ -263,13 +270,6 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1add_1builtin
 	(*env)->ReleaseStringUTFChars(env, name, p);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1error_1quark
-(JNIEnv *env, jclass cls)
-{
-    GQuark quark = (GQuark)gtk_icon_theme_error_quark();
-    return getHandleFromPointer(env, (void *)&quark);
-}
-
 JNIEXPORT jintArray JNICALL Java_org_gnu_gtk_IconTheme_gtk_1icon_1theme_1get_1icon_1sizes
 (JNIEnv *env, jclass cls, jobject icon_theme, jstring icon_name)
 {
