@@ -12,6 +12,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_ItemFactory.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -126,6 +127,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ItemFactory_gtk_1item_1factory_1get_1
     return result;
 }
 
+  // Not going to bother fixing, class is deprecated anyways.
+#ifdef ZERO
 /*
  * Class:     org.gnu.gtk.ItemFactory
  * Method:    gtk_item_factory_get_widget_by_action
@@ -138,7 +141,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ItemFactory_gtk_1item_1factory_1get_1
     return getGObjectHandle(env, (GObject *)
     		gtk_item_factory_get_widget_by_action (ifactory_g, action_g));
 }
+#endif
 
+  /* Class is deprecated, why fix something that won't be here? */
+#ifdef ZERO
 /*
  * Class:     org.gnu.gtk.ItemFactory
  * Method:    gtk_item_factory_get_item_by_action
@@ -151,6 +157,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ItemFactory_gtk_1item_1factory_1get_1
     return getGObjectHandle(env, (GObject *)
     		gtk_item_factory_get_item_by_action (ifactory_g, action_g));
 }
+#endif
 
 /*
  * Class:     org.gnu.gtk.ItemFactory
@@ -166,6 +173,9 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_ItemFactory_gtk_1item_1factory_1create_1
     gtk_item_factory_create_item (ifactory_g, entry_g, callbackData_g, callbackType_g);
 }
 
+
+  /* Broken, won't fix. Deprecated */
+#ifdef ZERO
 /*
  * Class:     org.gnu.gtk.ItemFactory
  * Method:    gtk_item_factory_create_items
@@ -179,6 +189,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_ItemFactory_gtk_1item_1factory_1create_1
     gpointer *callbackData_g = (gpointer *)callbackData;
     gtk_item_factory_create_items (ifactory_g, numEntries_g, entries_g, callbackData_g);
 }
+#endif
 
 /*
  * Class:     org.gnu.gtk.ItemFactory
