@@ -12,12 +12,13 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_ItemFactoryEntry.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-gchar * GtkItemFactoryEntry_get_path (GtkItemFactoryEntry * cptr) 
+static gchar * GtkItemFactoryEntry_get_path (GtkItemFactoryEntry * cptr) 
 {
     return cptr->path;
 }
@@ -34,7 +35,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gtk_ItemFactoryEntry_getPath (JNIEnv *env
     return (*env)->NewStringUTF(env, result_g);
 }
 
-gchar * GtkItemFactoryEntry_get_accelerator (GtkItemFactoryEntry * cptr) 
+static gchar * GtkItemFactoryEntry_get_accelerator (GtkItemFactoryEntry * cptr) 
 {
     return cptr->accelerator;
 }
@@ -51,7 +52,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gtk_ItemFactoryEntry_getAccelerator (JNIE
     return (*env)->NewStringUTF(env, result_g);
 }
 
-gchar * GtkItemFactoryEntry_get_item_type (GtkItemFactoryEntry * cptr) 
+static gchar * GtkItemFactoryEntry_get_item_type (GtkItemFactoryEntry * cptr) 
 {
     return cptr->item_type;
 }
