@@ -13,6 +13,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_TextBuffer.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -316,7 +317,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1create_
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
     return 
-        getGObjectHandle(env, (GObject *)
+        getGObjectHandleAndRef(env, (GObject *)
                              gtk_text_buffer_create_child_anchor (buffer_g, 
                                                                   iter_g));
 }
@@ -338,7 +339,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1create_
                                                        (gboolean)leftGravity);
     g_assert(result != NULL);
     (*env)->ReleaseStringUTFChars(env, markName, utf);
-    return getGObjectHandle(env, (GObject *) result);
+    return getGObjectHandleAndRef(env, (GObject *) result);
 }
 
 /*
@@ -382,7 +383,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1ma
     GtkTextMark *mark = gtk_text_buffer_get_mark (buffer_g, 
                                                   (gchar*)utf);
     (*env)->ReleaseStringUTFChars(env, name, utf);
-    return getGObjectHandle(env, (GObject *) mark);
+    return getGObjectHandleAndRef(env, (GObject *) mark);
 }
 
 /*
@@ -424,7 +425,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1in
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    return getGObjectHandle(env, (GObject *) gtk_text_buffer_get_insert (buffer_g));
+    return getGObjectHandleAndRef(env, (GObject *) gtk_text_buffer_get_insert (buffer_g));
 }
 
 /*
@@ -436,7 +437,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1se
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    return getGObjectHandle(env, (GObject *) gtk_text_buffer_get_selection_bound (buffer_g));
+    return getGObjectHandleAndRef(env, (GObject *) gtk_text_buffer_get_selection_bound (buffer_g));
 }
 
 /*
@@ -535,17 +536,19 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1remove_1al
  * Method:    gtk_text_buffer_get_iter_at_line_offset
  * Signature: (IIII)V
  */
-JNIEXPORT void JNICALL 
-Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line_1offset (JNIEnv *env, jclass cls, jobject buffer, jobject iter, jint lineNumber, jint charOffset) 
-{
-    GtkTextBuffer *buffer_g = 
-        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
-    gtk_text_buffer_get_iter_at_line_offset (buffer_g, iter_g,
-                                             (gint32)lineNumber, 
-                                             (gint32)charOffset);
-}
+//JNIEXPORT void JNICALL 
+//Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line_1offset (JNIEnv *env, jclass cls, jobject buffer, jobject iter, jint lineNumber, jint charOffset) 
+//{
+//    GtkTextBuffer *buffer_g = 
+//        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
+//    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
+//    gtk_text_buffer_get_iter_at_line_offset (buffer_g, iter_g,
+//                                             (gint32)lineNumber, 
+//                                             (gint32)charOffset);
+//}
 
+/* No java method */
+#ifdef ZERO
 /*
  * Class:     org.gnu.gtk.TextBuffer
  * Method:    gtk_text_buffer_get_iter_at_line_index
@@ -561,61 +564,10 @@ Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line_1index (JNIEn
                                             (gint32)lineNumber, 
                                             (gint32)byteIndex);
 }
+#endif
 
-/*
- * Class:     org.gnu.gtk.TextBuffer
- * Method:    gtk_text_buffer_get_iter_at_offset
- * Signature: (III)V
- */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1offset (JNIEnv *env, jclass cls, jobject buffer, jobject iter, jint charOffset) 
-{
-    GtkTextBuffer *buffer_g = 
-        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
-    gtk_text_buffer_get_iter_at_offset (buffer_g, iter_g,
-                                        (gint32)charOffset);
-}
-
-/*
- * Class:     org.gnu.gtk.TextBuffer
- * Method:    gtk_text_buffer_get_iter_at_line
- * Signature: (III)V
- */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line (JNIEnv *env, jclass cls, jobject buffer, jobject iter, jint lineNumber) 
-{
-    GtkTextBuffer *buffer_g = 
-        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
-    gtk_text_buffer_get_iter_at_line (buffer_g, iter_g,
-                                      (gint32)lineNumber);
-}
-
-/*
- * Class:     org.gnu.gtk.TextBuffer
- * Method:    gtk_text_buffer_get_start_iter
- * Signature: (II)V
- */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1start_1iter (JNIEnv *env, jclass cls, jobject buffer, jobject iter) 
-{
-    GtkTextBuffer *buffer_g = 
-        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
-    gtk_text_buffer_get_start_iter (buffer_g, iter_g);
-}
-
-/*
- * Class:     org.gnu.gtk.TextBuffer
- * Method:    gtk_text_buffer_get_end_iter
- * Signature: (II)V
- */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1end_1iter (JNIEnv *env, jclass cls, jobject buffer, jobject iter) 
-{
-    GtkTextBuffer *buffer_g = 
-        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
-    gtk_text_buffer_get_end_iter (buffer_g, iter_g);
-}
-
+  /* Broken, and no visible API. commenting out*/
+#ifdef ZERO
 /*
  * Class:     org.gnu.gtk.TextBuffer
  * Method:    gtk_text_buffer_get_bounds
@@ -629,36 +581,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1bound
     GtkTextIter *end_g = (GtkTextIter*)getPointerFromHandle(env, end);
     gtk_text_buffer_get_bounds (buffer_g, start_g, end_g);
 }
-
-/*
- * Class:     org.gnu.gtk.TextBuffer
- * Method:    gtk_text_buffer_get_iter_at_mark
- * Signature: (III)V
- */
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1mark (JNIEnv *env, jclass cls, jobject buffer, jobject iter, jobject mark) 
-{
-    GtkTextBuffer *buffer_g = 
-        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
-    GtkTextMark *mark_g = (GtkTextMark*)getPointerFromHandle(env, mark);
-    gtk_text_buffer_get_iter_at_mark (buffer_g, iter_g, mark_g);
-}
-
-/*
- * Class:     org.gnu.gtk.TextBuffer
- * Method:    gtk_text_buffer_get_iter_at_child_anchor
- * Signature: (III)V
- */
-JNIEXPORT void JNICALL 
-Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1child_1anchor (JNIEnv *env, jclass cls, jobject buffer, jobject iter, jobject anchor) 
-{
-    GtkTextBuffer *buffer_g = 
-        (GtkTextBuffer*)getPointerFromHandle(env, buffer);
-    GtkTextIter *iter_g = (GtkTextIter*)getPointerFromHandle(env, iter);
-    GtkTextChildAnchor *anchor_g = 
-        (GtkTextChildAnchor*)getPointerFromHandle(env, anchor);
-    gtk_text_buffer_get_iter_at_child_anchor (buffer_g, iter_g, anchor_g);
-}
+#endif
 
 /*
  * Class:     org.gnu.gtk.TextBuffer
@@ -761,6 +684,8 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1paste_1cli
                                      (gboolean)defaultEditable);
 }
 
+  /* Broken and not visible, commenting out */
+#ifdef ZERO
 /*
  * Class:     org.gnu.gtk.TextBuffer
  * Method:    gtk_text_buffer_get_selection_bounds
@@ -776,6 +701,7 @@ Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1selection_1bounds (JNIEnv *e
     return (jboolean) gtk_text_buffer_get_selection_bounds(buffer_g, 
                                                            start_g, end_g);
 }
+#endif
 
 /*
  * Class:     org.gnu.gtk.TextBuffer
@@ -837,13 +763,14 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_insert_1with_1tag (JNIEnv *en
     (*env)->ReleaseStringUTFChars(env, tag, tag_g);
 }
 	
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_create_1tag ( JNIEnv *env, jclass cls, jobject buffer, jstring name )
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_create_1tag
+		(JNIEnv *env, jclass cls, jobject buffer, jstring name)
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     const char *name_g = (*env)->GetStringUTFChars(env, name, NULL);
     jobject retval = 
-        getGObjectHandle(env, (GObject *) gtk_text_buffer_create_tag(buffer_g, 
+        getGObjectHandleAndRef(env, (GObject *) gtk_text_buffer_create_tag(buffer_g, 
                                                         name_g, NULL));
     (*env)->ReleaseStringUTFChars(env, name, name_g);
     return retval;
@@ -883,7 +810,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1se
     return getTextIter(env, end_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line_1offsetMOD
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line_1offset
 		(JNIEnv *env, jclass cls, jobject buffer, jint lineNumber, jint charOffset) 
 {
     GtkTextBuffer *buffer_g = 
@@ -895,7 +822,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
                                              (gint32)charOffset);
     return getTextIter(env, iter_g);
 }
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1offsetMOD
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1offset
 		(JNIEnv *env, jclass cls, jobject buffer, jint charOffset) 
 {
     GtkTextBuffer *buffer_g = 
@@ -907,7 +834,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
     return getTextIter(env, iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1lineMOD
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1line
 		(JNIEnv *env, jclass cls, jobject buffer, jint lineNumber) 
 {
     GtkTextBuffer *buffer_g = 
@@ -919,7 +846,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
     return getTextIter(env, &iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1markMOD
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1mark
 		(JNIEnv *env, jclass cls, jobject buffer, jobject mark) 
 {
     GtkTextBuffer *buffer_g = 
@@ -932,19 +859,21 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1it
     return getTextIter(env, iter_g);
 }
     
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1child_1anchorMOD
-		(JNIEnv *env, jclass cls, jobject buffer, jint anchor) 
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1iter_1at_1child_1anchor
+		(JNIEnv *env, jclass cls, jobject buffer, jobject anchor) 
 {
     GtkTextBuffer *buffer_g = 
         (GtkTextBuffer*)getPointerFromHandle(env, buffer);
     GtkTextIter *iter_g = (GtkTextIter *)g_malloc(sizeof(GtkTextIter));
+    GtkTextChildAnchor *anchor_g = getPointerFromHandle(env, anchor);
+
     gtk_text_buffer_get_iter_at_child_anchor (buffer_g, 
                                               iter_g, 
-                                              (GtkTextChildAnchor*)anchor);
+                                              anchor_g);
     return getTextIter(env, iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1start_1iterMOD
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1start_1iter
 		(JNIEnv *env, jclass cls, jobject buffer) 
 {
     GtkTextBuffer *buffer_g = 
@@ -954,7 +883,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1st
     return getTextIter(env, iter_g);
 }
 
-JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1end_1iterMOD
+JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1end_1iter
 		(JNIEnv *env, jclass cls, jobject buffer) 
 {
     GtkTextBuffer *buffer_g = 
@@ -964,7 +893,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1get_1en
     return getTextIter(env, iter_g);
 }
 
-JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1paste_1clipboardInsertPosisition
+JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1paste_1clipboardInsertPosition
 		(JNIEnv *env, jclass cls, jobject buffer, jobject clipboard, jboolean defaultEditable) 
 {
     GtkTextBuffer *buffer_g = 
@@ -977,6 +906,21 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1paste_1cli
                                      (gboolean)defaultEditable);
 }
 
+/* GTK 2.6 additions. */
+
+JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1backspace
+(JNIEnv *env, jclass cls, jobject buffer, jobject iter, jboolean interactive, jboolean default_editable)
+{
+    GtkTextBuffer * buffer_g = 
+        (GtkTextBuffer *)getPointerFromHandle(env, buffer);
+    GtkTextIter * iter_g = (GtkTextIter *)getPointerFromHandle(env, iter);
+    gboolean interactive_g = (gboolean)interactive;
+    gboolean default_editable_g = (gboolean)default_editable;
+    return (jboolean)gtk_text_buffer_backspace(buffer_g, iter_g, 
+                                               interactive_g, 
+                                               default_editable_g);
+}
+
 #ifdef __cplusplus
 }
 
