@@ -13,6 +13,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_TextView.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -250,8 +251,8 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1iter_1
     x_g = (gint32) x;
     y_g = (gint32) y;
     gtk_text_view_get_iter_at_location (textView_g, &iter_g, x_g, y_g);
-    getGBoxedHandle(env, &iter_g, gtk_text_iter_get_type(), gtk_text_iter_copy, 
-    		(GBoxedFreeFunc) gtk_text_iter_free);
+    return getGBoxedHandle(env, &iter_g, gtk_text_iter_get_type(), 
+    		(GBoxedCopyFunc) gtk_text_iter_copy,  (GBoxedFreeFunc) gtk_text_iter_free);
 }
 
 /*
@@ -345,7 +346,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1get_1window
     GtkTextView *textView_g = 
         (GtkTextView *)getPointerFromHandle(env, textView);
     GtkTextWindowType win_g = (GtkTextWindowType) win;
-    return getGObjectHandle(env, (GObject *) gtk_text_view_get_window (textView_g, win_g));
+    return getGObjectHandleAndRef(env, (GObject *) gtk_text_view_get_window (textView_g, win_g));
 }
 
 /*
@@ -818,20 +819,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_TextView_gtk_1text_1view_1set_1overwrite
     gtk_text_view_set_overwrite( textView_g, setting_g );
 }
 
-/* GTK 2.6 additions. */
 
-JNIEXPORT jboolean JNICALL Java_org_gnu_gtk_TextBuffer_gtk_1text_1buffer_1backspace
-(JNIEnv *env, jclass cls, jobject buffer, jobject iter, jboolean interactive, jboolean default_editable)
-{
-    GtkTextBuffer * buffer_g = 
-        (GtkTextBuffer *)getPointerFromHandle(env, buffer);
-    GtkTextIter * iter_g = (GtkTextIter *)getPointerFromHandle(env, iter);
-    gboolean interactive_g = (gboolean)interactive;
-    gboolean default_editable_g = (gboolean)default_editable;
-    return (jboolean)gtk_text_buffer_backspace(buffer_g, iter_g, 
-                                               interactive_g, 
-                                               default_editable_g);
-}
 
 #ifdef __cplusplus
 }
