@@ -13,6 +13,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_TreeSortableHelper.h"
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -72,7 +73,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_TreeSortableHelper_gtk_1tree_1sortable_1
     }
 }
 
-gint static listSortFunction( GtkTreeModel *model, GtkTreeIter *a, 
+static gint listSortFunction( GtkTreeModel *model, GtkTreeIter *a, 
                               GtkTreeIter *b, gpointer data ) {
     jobject model_handle;
     jobject iter_a;
