@@ -10,8 +10,10 @@
 #include <jni.h>
 #include <sys/types.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_UIManager.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -34,7 +36,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1get_1type(JN
  */
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1new(JNIEnv *env, jclass cls)
 {
-    return getHandleFromPointer(env, gtk_ui_manager_new());
+    return getGObjectHandle(env, (GObject *) gtk_ui_manager_new());
 }
 
 /*
@@ -94,7 +96,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1remove_1acti
 JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1get_1action_1groups(JNIEnv *env, jclass cls, jobject uim)
 {
     GtkUIManager *uim_g = (GtkUIManager *)getPointerFromHandle(env, uim);
-    return getHandleArrayFromGList(env,gtk_ui_manager_get_action_groups(uim_g));
+    return getGObjectHandlesFromGList(env,gtk_ui_manager_get_action_groups(uim_g));
 }
 
 /*
@@ -105,7 +107,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1get_
 JNIEXPORT jobject JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1get_1accel_1group(JNIEnv *env, jclass cls, jobject uim)
 {
     GtkUIManager *uim_g = (GtkUIManager *)getPointerFromHandle(env, uim);
-    return getHandleFromPointer(env, gtk_ui_manager_get_accel_group(uim_g));
+    return getGObjectHandle(env, (GObject *) gtk_ui_manager_get_accel_group(uim_g));
 }
 
 /*
@@ -117,7 +119,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1get_1widg
 {
     GtkUIManager *uim_g = (GtkUIManager *)getPointerFromHandle(env, uim);
     const gchar* p = (*env)->GetStringUTFChars(env, path, NULL);
-    jobject ret = getHandleFromPointer(env, gtk_ui_manager_get_widget(uim_g, p));
+    jobject ret = getGObjectHandle(env, (GObject *) gtk_ui_manager_get_widget(uim_g, p));
     (*env)->ReleaseStringUTFChars(env, path, p);
     return ret;
 }
@@ -131,7 +133,7 @@ JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1get_
 {
     GtkUIManager *uim_g = (GtkUIManager *)getPointerFromHandle(env, uim);
     GtkUIManagerItemType types_g = (GtkUIManagerItemType)types;
-    return getHandleArrayFromGSList(env,gtk_ui_manager_get_toplevels(uim_g, types_g));
+    return getGObjectHandlesFromGSList(env,gtk_ui_manager_get_toplevels(uim_g, types_g));
 }
 
 /*
@@ -143,7 +145,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1get_1acti
 {
     GtkUIManager *uim_g = (GtkUIManager *)getPointerFromHandle(env, uim);
     const gchar* p = (*env)->GetStringUTFChars(env, path, NULL);
-    jobject ret = getHandleFromPointer(env, gtk_ui_manager_get_action(uim_g, p));
+    jobject ret = getGObjectHandle(env, (GObject *) gtk_ui_manager_get_action(uim_g, p));
     (*env)->ReleaseStringUTFChars(env, path, p);
     return ret;
 }
@@ -156,10 +158,11 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1add_1ui_1fro
 {
     GtkUIManager *uim_g = (GtkUIManager *)getPointerFromHandle(env, uim);
     const gchar* b = (*env)->GetStringUTFChars(env, buffer, NULL);
-    GError* err = g_new(GError, 1);
+    GError* err = NULL;
     jint ret = (jint)gtk_ui_manager_add_ui_from_string(uim_g, b, (gint)len, &err);
     (*env)->ReleaseStringUTFChars(env, buffer, b);
-    g_free( err );
+    if (err != NULL)
+	    g_free( err );
     return ret;
 }
 
@@ -172,10 +175,11 @@ JNIEXPORT jint JNICALL Java_org_gnu_gtk_UIManager_gtk_1ui_1manager_1add_1ui_1fro
 {
     GtkUIManager *uim_g = (GtkUIManager *)getPointerFromHandle(env, uim);
     const gchar* f = (*env)->GetStringUTFChars(env, filename, NULL);
-    GError* err = g_new(GError, 1);
+    GError* err = NULL;
     jint ret = (jint)gtk_ui_manager_add_ui_from_file(uim_g, f, &err);
     (*env)->ReleaseStringUTFChars(env, filename, f);
-    g_free( err );
+    if (NULL != err)
+	    g_free( err );
     return ret;
 }
 
