@@ -12,12 +12,13 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_pango_AttrShape.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-PangoRectangle *pango_rectangle_new( PangoRectangle *orig ) {
+static PangoRectangle *pango_rectangle_new( PangoRectangle *orig ) {
     PangoRectangle *nr = g_new( PangoRectangle, 1 );
     nr->x = orig->x;
     nr->y = orig->y;
