@@ -12,6 +12,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_pango_TabArray.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -126,9 +127,9 @@ JNIEXPORT void JNICALL Java_org_gnu_pango_TabArray_pango_1tab_1array_1get_1tab (
 {
     PangoTabArray *tabArray_g = (PangoTabArray *)getPointerFromHandle(env, tabArray);
     gint32 tabIndex_g = (gint32) tabIndex;
-    PangoTabAlign *alignment_g = (PangoTabAlign*)alignment;
+    PangoTabAlign alignment_g = (PangoTabAlign)alignment;
     gint *location_g = (gint *) (*env)->GetIntArrayElements (env, location, NULL);
-    pango_tab_array_get_tab (tabArray_g, tabIndex_g, alignment_g, location_g);
+    pango_tab_array_get_tab (tabArray_g, tabIndex_g, &alignment_g, location_g);
     (*env)->ReleaseIntArrayElements (env, location, (jint *) location_g, 0);
 }
 
